meetingrequest/mrgui/src/cesmrview.cpp
branchRCL_3
changeset 80 726fba06891a
parent 64 3533d4323edc
--- a/meetingrequest/mrgui/src/cesmrview.cpp	Wed Sep 15 11:52:37 2010 +0300
+++ b/meetingrequest/mrgui/src/cesmrview.cpp	Wed Oct 13 14:11:15 2010 +0300
@@ -730,16 +730,10 @@
                                 NMRLayoutManager::EMRLayoutMRNaviArrowRight );
                 TRect naviArrowRightRect( naviArrowRightLayoutRect.Rect() );
     
-                // Right arrow needs to be moved left the amount of
-                // possible toolbar width in landscape
-                TInt scrollWidth( 0 );
-                if( iScrollBar )
-                    {
-                    scrollWidth = iScrollBar->Rect().Width();
-                    }
-                
-                naviArrowRightRect.Move( scrollWidth, 0 );
-    
+                // Right arrow needs to be moved right the amount of
+                // stripe width in landscape
+                naviArrowRightRect.Move( iStripeRect.Width(), 0 );
+
                 iNaviArrowRight->SetRect( naviArrowRightRect );
                 }
             }